@@ -100,13 +100,49 @@ def get_list_targets(folder=""):
     upipe.print_info("Potential Targets -- list: {0}".format(str(list_targets)))
     return list_targets
 
+
+def build_dict_datasets(data_path="", str_dataset=default_str_dataset, ndigits=default_ndigits):
+    """Build a dictionary of datasets for each target in the sample
+
+    Input
+    ------
+    data_path: str
+       Path of the target data
+    str_dataset: str
+        Prefix string for datasets
+    ndigits: int
+       Number of digits to format the name of the dataset
+
+    Returns
+    -------
+    dict_dataset: dict
+
+    """
+    list_targets = get_list_targets(data_path)
+    dict_dataset = {}
+
+    npath = os.path.normpath(data_path)
+    s_npath = npath.split(os.sep)
+
+    for target in list_targets:
+        target_path = f"{data_path}/{target}/"
+        list_datasets = get_list_datasets(target_path, str_dataset, ndigits)
+        dict_t = {}
+        for ds in list_datasets:
+            dict_t[ds] = 1
+
+        dict_dataset[target] = [s_npath[-1], dict_t]
+
+    return dict_dataset
+        
+
 def build_dict_exposures(target_path="", str_dataset=default_str_dataset,
                          ndigits=default_ndigits, show_pointings=False):
     """Build a dictionary of exposures using the list of datasets found for the
     given dataset path
 
-    Parameters
-    ----------
+    Input
+    ------
     target_path: str
        Path of the target data
     str_dataset: str
@@ -144,7 +180,7 @@ def build_dict_exposures(target_path="", str_dataset=default_str_dataset,
     return dict_expos
 
 def get_list_datasets(target_path="", str_dataset=default_str_dataset,
-                      ndigits=default_ndigits):
+                      ndigits=default_ndigits, verbose=False):
     """Getting the list of existing datasets for a given target path
 
     Input
@@ -161,14 +197,20 @@ def get_list_datasets(target_path="", str_dataset=default_str_dataset,
     list_datasets: list of int
     """
     # Done by scanning the target path
-    upipe.print_info(f"Searching datasets in {target_path} with {str_dataset} prefix")
+    if verbose:
+        upipe.print_info(f"Searching datasets in {target_path} with {str_dataset} prefix")
     all_folders = glob.glob(f"{target_path}/{str_dataset}*")
-    upipe.print_info(f"All folder names  = {all_folders}")
+    if verbose:
+        upipe.print_info(f"All folder names  = {all_folders}")
     all_datasets = [os.path.split(s)[-1] for s in all_folders]
-    upipe.print_info(f"All detected folder names  = {all_datasets}")
+    all_datasets.sort()
+    if verbose:
+        upipe.print_info(f"All detected folder names  = {all_datasets}")
     r = re.compile(f"{str_dataset}\d{{{ndigits}}}$")
     good_datasets = [f for f in all_datasets if r.match(f)]
-    upipe.print_info(f"All good folder names  = {good_datasets}")
+    good_datasets.sort()
+    if verbose:
+        upipe.print_info(f"All good folder names  = {good_datasets}")
     list_datasets = []
     for folder in good_datasets:
         list_datasets.append(int(folder[-int(ndigits):]))
@@ -385,10 +427,6 @@ class MusePointings(SofPipe, PipeRecipes):
         self.pipe_params.init_default_param(dict_combined_folders)
         self._dict_combined_folders = dict_combined_folders
 
-        # List of datasets to process
-        self.list_datasets = self._check_list_datasets(list_datasets)
-        # List of pointings to process
-        self.list_pointings = self._check_list_pointings(list_pointings)
         # Setting all the useful paths
         self.set_fullpath_names()
         self.paths.log_filename = joinpath(self.paths.log, log_filename)
@@ -396,11 +434,20 @@ class MusePointings(SofPipe, PipeRecipes):
         # and Recording the folder where we start
         self.paths.orig = os.getcwd()
 
+        check = kwargs.pop("check", True)
+        if check:
+            # List of datasets to process
+            self.list_datasets = self._check_list_datasets(list_datasets)
+            # List of pointings to process
+            self.list_pointings = self._check_list_pointings(list_pointings)
         # END Set up params =======================================
 
         # =========================================================== 
         # ---------------------------------------------------------
         # Create the Combined folder
+        # Making the output folders in a safe mode
+        if self.verbose:
+            upipe.print_info("Creating directory structure")
         upipe.safely_create_folder(self.paths.data, verbose=verbose)
 
         # Go to the Combined Folder
@@ -412,16 +459,14 @@ class MusePointings(SofPipe, PipeRecipes):
 
         # Checking input datasets and pixtables
         self._pixtab_in_comb_folder = kwargs.pop("pixtab_in_comb_folder", True)
-        self._get_list_reduced_pixtables(dict_exposures)
+        if check:
+            self._get_list_reduced_pixtables(dict_exposures)
 
         # Checking input offset table and corresponding pixtables
-        self._check_offset_table(name_offset_table, folder_offset_table)
+        if check:
+            self._check_offset_table(name_offset_table, folder_offset_table)
         # END CHECK UP ============================================
 
-        # Making the output folders in a safe mode
-        if self.verbose:
-            upipe.print_info("Creating directory structure")
-
         # Going back to initial working directory
         self.goto_origfolder()
 
@@ -467,6 +512,7 @@ class MusePointings(SofPipe, PipeRecipes):
         list_datasets after checking they exist
         """
         listname = kwargs.pop("listname", "Datasets")
+        verbose = kwargs.pop("verbose", False)
 
         if default_list is None:
             default_list = self.full_list_datasets
@@ -475,8 +521,9 @@ class MusePointings(SofPipe, PipeRecipes):
             # This is using all the existing datasets
             return default_list
         else:
-            upipe.print_info(f"Wished {listname} list = {list_datasets}")
-            upipe.print_warning(f"Target default {listname} list = {default_list}")
+            if verbose:
+                upipe.print_info(f"Wished {listname} list = {list_datasets}")
+                upipe.print_warning(f"Target default {listname} list = {default_list}")
             # Checked ones
             checked_list_datasets = list(set(list_datasets) & set(default_list))
             # Not existing ones
@@ -508,6 +555,7 @@ class MusePointings(SofPipe, PipeRecipes):
     def _get_list_reduced_pixtables(self, dict_exposures=None):
         """Check if datasets and dictionary are compatible
         """
+        upipe.print_info("Checking the list of reduced PixTables")
         # Dictionary of exposures to select per dataset
         self.dict_exposures = dict_exposures
 
@@ -746,9 +794,8 @@ class MusePointings(SofPipe, PipeRecipes):
         for name in self.pipe_params._dict_folders_target:
             setattr(self.paths, name, joinpath(self.paths.target, self.pipe_params._dict_folders_target[name]))
 
-    def create_reference_wcs(self, pointings_wcs=True, mosaic_wcs=True,
-                             reference_cube=True, refcube_name=None,
-                             **kwargs):
+    def create_reference_wcs(self, pointings_wcs=True, mosaic_wcs=True, reference_cube=True,
+                             refcube_name=None, **kwargs):
         """Create the WCS reference files, for all individual pointings and for
         the mosaic.
 
@@ -800,10 +847,8 @@ class MusePointings(SofPipe, PipeRecipes):
                                         lambdaminmax_wcs=lambdaminmax_for_mosaic,
                                         refcube_name=wcs_refcube_name)
 
-    def run_combine_all_single_pointings(self, add_suffix="",
-                                         sof_filename='pointings_combine',
-                                         list_pointings=None,
-                                         **kwargs):
+    def run_combine_all_single_pointings(self, add_suffix="", sof_filename='pointings_combine',
+                                         list_pointings=None, **kwargs):
         """Run for all pointings individually, provided in the
         list of pointings, by just looping over the pointings.
 
@@ -835,8 +880,7 @@ class MusePointings(SofPipe, PipeRecipes):
                                           sof_filename=sof_filename,
                                           **kwargs)
 
-    def run_combine_single_pointing(self, pointing, add_suffix="",
-                                    sof_filename='pointing_combine',
+    def run_combine_single_pointing(self, pointing, add_suffix="", sof_filename='pointing_combine',
                                     **kwargs):
         """Running the combine routine on just one single pointing
 
@@ -878,13 +922,10 @@ class MusePointings(SofPipe, PipeRecipes):
                 ref_wcs = f"{prefix_wcs}{prefix_final_cube}_{get_pointing_name(pointing)}.fits"
 
         # Running the combine for that single pointing
-        self.run_combine(list_pointings=[int(pointing)], suffix=suffix,
-                         sof_filename=sof_filename,
-                         ref_wcs=ref_wcs,
-                         **kwargs)
+        self.run_combine(list_pointings=[int(pointing)], suffix=suffix, sof_filename=sof_filename,
+                         ref_wcs=ref_wcs, **kwargs)
 
-    def create_all_pointings_wcs(self, filter_list="white",
-                                 list_pointings=None, **kwargs):
+    def create_all_pointings_wcs(self, filter_list="white", list_pointings=None, **kwargs):
         """Create all pointing masks one by one
         as well as the wcs for each individual pointings. Using the grid
         from the global WCS of the mosaic but restricting it to the 
@@ -906,9 +947,8 @@ class MusePointings(SofPipe, PipeRecipes):
             _ = self.create_pointing_wcs(pointing=pointing,
                                          filter_list=filter_list, **kwargs)
 
-    def create_pointing_wcs(self, pointing,
-            lambdaminmax_mosaic=lambdaminmax_for_mosaic,
-            filter_list="white", **kwargs):
+    def create_pointing_wcs(self, pointing, lambdaminmax_mosaic=lambdaminmax_for_mosaic,
+                            filter_list="white", **kwargs):
         """Create the mask of a given pointing
         And also a WCS file which can then be used to compute individual
         pointings with a fixed WCS.
@@ -977,23 +1017,21 @@ class MusePointings(SofPipe, PipeRecipes):
         return full_cname
 
     def extract_combined_narrow_wcs(self, name_cube=None, **kwargs):
-        """Create the reference WCS from the full mosaic with
-        only 2 lambdas
+        """Create the reference WCS from the full mosaic with only 2 lambdas
 
         Input
         -----
         name_cube: str
-            Name of the cube. Can be None, and then the final
-            datacube from the combine folder will be used.
+            Name of the cube. Can be None, and then the final datacube from the combine
+            folder will be used.
         wave1: float - optional
-            Wavelength taken for the extraction. Should only
-            be present in all spaxels you wish to get.
+            Wavelength taken for the extraction. Should only be present in all spaxels
+            you wish to get.
         prefix_wcs: str - optional
-            Prefix to be added to the name of the input cube.
-            By default, will use "refwcs".
-        add_targetname: bool [True]
-            Add the name of the target to the name of the output
-            WCS reference cube. Default is True.
+            Prefix to be added to the name of the input cube. By default, will use "refwcs".
+        add_targetname: bool default=True
+            Add the name of the target to the name of the output WCS reference cube.
+            Default is True.
 
         Creates:
             Combined narrow band WCS cube
@@ -1034,9 +1072,8 @@ class MusePointings(SofPipe, PipeRecipes):
         upipe.print_info("...Done")
         return full_cname
 
-    def create_combined_wcs(self, refcube_name=None,
-            lambdaminmax_wcs=lambdaminmax_for_wcs,
-            **kwargs):
+    def create_combined_wcs(self, refcube_name=None, lambdaminmax_wcs=lambdaminmax_for_wcs,
+                            **kwargs):
         """Create the reference WCS from the full mosaic
         with a given range of lambda.
 
